==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => ' <b>Important group:</b> מאוד מומלץ לסמן מילת מפתח בקבוצה הזאת.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'מנהלי האתר',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'עורכים',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'אורחים של אתר ציבורי כשהם מוסיפים הודעה בפורום ',

	// I
	'icone_creation_groupe_mots' => 'צור קבוצה חדשה של מילות מפתח',
	'icone_creation_mots_cles' => 'צור מילת מפתח חדשה',
	'icone_modif_groupe_mots' => 'שנה את קבוצת מילות המפתח האלו',
	'icone_modifier_mot' => 'שנה מילת מפתח זאת',
	'icone_mots_cles' => 'מילות מפתח',
	'icone_supprimer_groupe_mots' => 'מחק קבוצה זו',
	'icone_voir_tous_mots_cles' => 'הצג את כל מילות המפתח',
	'info_articles_lies_mot' => 'מאמרים מקושרים עם מילת המפתח הזו',
	'info_changer_nom_groupe' => ':שנה את שם הקבוצה הזאת',
	'info_creation_mots_cles' => 'צור ועצב את מילות המפתח של האתר פה',
	'info_dans_groupe' => ':בקבוצה',
	'info_groupe_important' => 'קבוצה חשובה',
	'info_modifier_mot' => 'ערוך את מילה המפתח :',
	'info_mots_cles' => 'מילות מפתח',
	'info_mots_cles_association' => ':מילות מפתח בקבוצה זו יכולות להתחבר עם',
	'info_oui_suppression_mot_cle' => '.אני רוצה למחוק את מילת המפתח הזו לתמיד',
	'info_question_mots_cles' => '?האם אתה רוצה להשתמש המילות מפתח באתרך',
	'info_qui_attribue_mot_cle' => 'מילות המפתח בקבוצה זו יכולים להיות מוקצים על ידי:',
	'info_retirer_mot' => 'הסרת מילת מפתח זו',
	'info_retirer_mots' => 'הסרת כל מילות מפתח',
	'info_supprimer_mot' => 'למחוק את המילה',

	// L
	'logo_mot_cle' => 'למס מילה מפתח',

	// T
	'texte_nouveau_mot' => 'מילה חדשה',
	'titre_mots_tous' => 'מילות מפתח',
	'titre_page_mots_tous' => 'מילות מפתח'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => ' <b>Important group:</b> מאוד מומלץ לסמן מילת מפתח בקבוצה הזאת.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'מנהלי האתר',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'עורכים',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'אורחים של אתר ציבורי כשהם מוסיפים הודעה בפורום ',

	// I
	'icone_creation_groupe_mots' => 'צור קבוצה חדשה של מילות מפתח',
	'icone_creation_mots_cles' => 'צור מילת מפתח חדשה',
	'icone_modif_groupe_mots' => 'שנה את קבוצת מילות המפתח האלו',
	'icone_modifier_mot' => 'שנה מילת מפתח זאת',
	'icone_mots_cles' => 'מילות מפתח',
	'icone_supprimer_groupe_mots' => 'מחק קבוצה זו',
	'icone_voir_tous_mots_cles' => 'הצג את כל מילות המפתח',
	'info_articles_lies_mot' => 'מאמרים מקושרים עם מילת המפתח הזו',
	'info_changer_nom_groupe' => ':שנה את שם הקבוצה הזאת',
	'info_creation_mots_cles' => 'צור ועצב את מילות המפתח של האתר פה',
	'info_dans_groupe' => ':בקבוצה',
	'info_groupe_important' => 'קבוצה חשובה',
	'info_modifier_mot' => 'ערוך את מילה המפתח :',
	'info_mots_cles' => 'מילות מפתח',
	'info_mots_cles_association' => ':מילות מפתח בקבוצה זו יכולות להתחבר עם',
	'info_oui_suppression_mot_cle' => '.אני רוצה למחוק את מילת המפתח הזו לתמיד',
	'info_question_mots_cles' => '?האם אתה רוצה להשתמש המילות מפתח באתרך',
	'info_qui_attribue_mot_cle' => 'מילות המפתח בקבוצה זו יכולים להיות מוקצים על ידי:',
	'info_retirer_mot' => 'הסרת מילת מפתח זו',
	'info_retirer_mots' => 'הסרת כל מילות מפתח',
	'info_supprimer_mot' => 'למחוק את המילה',

	// L
	'logo_mot_cle' => 'למס מילה מפתח',

	// T
	'texte_nouveau_mot' => 'מילה חדשה',
	'titre_mots_tous' => 'מילות מפתח',
	'titre_page_mots_tous' => 'מילות מפתח',
];
